#!/bin/bash

source clone_sources_utils.sh
source ../../bash_utils/helpers.sh

# Arguments
INSTALL_NAME=
IFS_BUNDLE_REPO=
IFS_BUNDLE_BRANCH=
GIT_BRANCH=
IFS_BUNDLE_ENV=
MN5_SOURCE_PATH=
FORCE=false
INSTALL=false

# 0. Check args:
parse_args "$@" 
check_required_args 
print_options

# 1. Cloning ifs-bundle to aux and get branch & commit info:
info "Cloning ifs bundle..."
[ -d aux_dir ] && rm -rdf aux_dir
git clone $IFS_BUNDLE_REPO $GIT_BRANCH aux_dir &> /dev/null
REPO_HASH=$(git -C aux_dir rev-parse --short HEAD)
REPO_BRANCH=$(git -C aux_dir rev-parse --abbrev-ref HEAD)
REPO_BRANCH="${REPO_BRANCH//\//.}"
REPO_ID="ifs-bundle-${REPO_BRANCH}-${REPO_HASH}"
[ -z $INSTALL_NAME ] || REPO_ID=$INSTALL_NAME
success "DONE"

# 3. Check if this branch is already there:
[ -d $REPO_ID ] && fatal "IFS-BUNDLE VERSION $REPO_ID ALREADY INSTALLED!"
info "Using $REPO_ID as version"
mv aux_dir $REPO_ID

# 2. Apply ifs-bundle env (if required)
[ -z $IFS_BUNDLE_ENV ] || source $IFS_BUNDLE_ENV 
[ -z $IFS_BUNDLE_ENV ] || cp $IFS_BUNDLE_ENV $REPO_ID
echo printenv | grep IFS_BUNDLE

# 4. Build the bundle
info "Building ifs bundle..."
cd $REPO_ID
./ifs-bundle create -j 8 --shallow
success "DONE"

# 5. Echo the lines to send to mn5 if required:
if [[ -z $MN5_SOURCE_PATH ]]; then
    info "Send to MN5 is disable"
    exit 0
fi
info "Sending data to $MN5_SOURCE_PATH ..."
[ -z $MN5_SOURCE_PATH ] && MN5_SOURCE_PATH=$DEF_MN5_DIR
MN5_SOURCE_PATH=$MN5_SOURCE_PATH/$REPO_ID
rsync -aP . $MN5_SOURCE_PATH > /dev/null
success "DONE"

# 6. Submit installation, if required:
if [ $INSTALL = true ]; then
    UTILS_REMOTE_FOLDER="/gpfs/projects/bsc32/DestinE/destine-utils/installation/ifs-bundle/"
    INSTALL_COMMAND="sbatch --qos compile-mn5-gpp.slurm $MN5_SOURCE_PATH"
    ssh mn5-gpp1 cd $UTILS_REMOTE_FOLDER && $INSTALL_COMMAND
    success "SUBMIT"
else
    success "Data upload to $MN5_SOURCE_PATH"
    success "To compile, you can use: ssh mn5-gpp1 cd /gpfs/projects/bsc32/DestinE/destine-utils/installation/ifs-bundle/ && sbatch --qos compile-mn5-gpp.slurm $MN5_SOURCE_PATH"
fi