#!/bin/bash

# Author: Victor Correal (victor.correal@bsc.es)
# Date  : 1/05/2024


usage() {
    echo "Use this script to create rundir from an installation"
    echo "Usage: $0 "
    echo -e "\t--installation-dir --ref-rundir | --resolution"
    echo -e "\t--rundir --env"
    echo -e "installation-dir must point to the location of the NEMO binary"
    echo -e "Available resolutions: "
    echo -e "hint: NEMO_SRC_BASE/cfgs/YOUR_CFG_NAME/EXP00 ."
    echo -e "USE ABSOLUTE PATHS! Use `$PWD` if you want to refer to the submission path"
}

parse_args() {
    OPTIONS=$(getopt -o "" --long install-dir:,ref-rundir:,rundir:,env:,help,force -n "$0" -- "$@")
    eval set -- "$OPTIONS"

    while true; do
        case "$1" in
            --install-dir)
                INSTALL_DIR="$2"
                shift 2
            ;;
            --ref-rundir)
                REF_RUNDIR="$2"
                shift 2
            ;;
            --rundir)
                RUNDIR="$2"
                shift 2
            ;;
            --env)
                ENV_FILE="$2"
                shift 2
            ;;
            --help)
                usage
                exit 0
            ;;
            --force)
                FORCE=true
                shift
            ;;
            --)
                shift
                break
            ;;
            *)
                usage
                exit 1
            ;;
        esac
    done
}

print_options() {
    info "============================CREATE RUNDIR=========================================="
    info "INSTALLATION: $INSTALL_DIR"
    info "REFERENCE RUNDIR: $REF_RUNDIR"
    info "RUNDIR: $RUNDIR"
    info "==================================================================================="

    if [ $FORCE = false ]; then
        echo -n "FINE? (Y/N)"
        read ANSWER
        case "$ANSWER" in
            [Yy])
                echo ""
                ;;
            [Nn])
                echo "ABORT..."
                exit 0
                ;;
            *)
                echo "ABORT"
                exit 1
                ;;
        esac
    else
        info "Force ENABLED, skip ask to the user"
    fi
}

check_required_args() {
    [ -z $INSTALL_DIR ] && fatal "Select install dir with --install-dir"
    [ -e $INSTALL_DIR/nemo ] || fatal "Unable to find nemo bin, check --install-dir ($INSTALL_DIR)"
    [ -z $REF_RUNDIR ] && fatal "Select resolution with --ref-rundir."
    [ -d $REF_RUNDIR ] || fatal "Unable to find reference rundir $REF_RUNDIR"
    [ -z $RUNDIR ] && fatal "Select the running directory with --rundir."
    [ -z $ENV_FILE ]  && fatal "Env file not set, use --env"
}
